Struct Shlex
struct Shlex<'a>(_)
An iterator that takes an input string and splits it into the words using the same syntax as the POSIX shell.
See bytes::Shlex.
Implementations
impl<'a> Shlex<'a>
fn new(in_str: &'a str) -> Self
impl<'a> Deref for Shlex<'a>
fn deref(self: &Self) -> &<Self as >::Target
impl<'a> DerefMut for Shlex<'a>
fn deref_mut(self: &mut Self) -> &mut <Self as >::Target
impl<'a> Freeze for Shlex<'a>
impl<'a> Iterator for Shlex<'a>
fn next(self: &mut Self) -> Option<String>
impl<'a> RefUnwindSafe for Shlex<'a>
impl<'a> Send for Shlex<'a>
impl<'a> Sync for Shlex<'a>
impl<'a> Unpin for Shlex<'a>
impl<'a> UnsafeUnpin for Shlex<'a>
impl<'a> UnwindSafe for Shlex<'a>
impl<I> IntoIterator for Shlex<'a>
fn into_iter(self: Self) -> I
impl<P, T> Receiver for Shlex<'a>
impl<T> Any for Shlex<'a>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Shlex<'a>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Shlex<'a>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Shlex<'a>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Shlex<'a>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Shlex<'a>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Shlex<'a>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>